# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from ....._types import SequenceNotStr
from ....._utils import PropertyInfo

__all__ = [
    "ConfigurationUpdateParams",
    "Config",
    "ConfigIngress",
    "ConfigIngressOriginRequest",
    "ConfigIngressOriginRequestAccess",
    "ConfigOriginRequest",
    "ConfigOriginRequestAccess",
]


class ConfigurationUpdateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    config: Config
    """The tunnel configuration and ingress rules."""


class ConfigIngressOriginRequestAccess(TypedDict, total=False):
    """
    For all L7 requests to this hostname, cloudflared will validate each request's Cf-Access-Jwt-Assertion request header.
    """

    aud_tag: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="audTag")]]
    """Access applications that are allowed to reach this hostname for this Tunnel.

    Audience tags can be identified in the dashboard or via the List Access policies
    API.
    """

    team_name: Required[Annotated[str, PropertyInfo(alias="teamName")]]

    required: bool
    """Deny traffic that has not fulfilled Access authorization."""


class ConfigIngressOriginRequest(TypedDict, total=False):
    """
    Configuration parameters for the public hostname specific connection settings between cloudflared and origin server.
    """

    access: ConfigIngressOriginRequestAccess
    """
    For all L7 requests to this hostname, cloudflared will validate each request's
    Cf-Access-Jwt-Assertion request header.
    """

    ca_pool: Annotated[str, PropertyInfo(alias="caPool")]
    """Path to the certificate authority (CA) for the certificate of your origin.

    This option should be used only if your certificate is not signed by Cloudflare.
    """

    connect_timeout: Annotated[int, PropertyInfo(alias="connectTimeout")]
    """Timeout for establishing a new TCP connection to your origin server.

    This excludes the time taken to establish TLS, which is controlled by
    tlsTimeout.
    """

    disable_chunked_encoding: Annotated[bool, PropertyInfo(alias="disableChunkedEncoding")]
    """Disables chunked transfer encoding. Useful if you are running a WSGI server."""

    http2_origin: Annotated[bool, PropertyInfo(alias="http2Origin")]
    """Attempt to connect to origin using HTTP2. Origin must be configured as https."""

    http_host_header: Annotated[str, PropertyInfo(alias="httpHostHeader")]
    """Sets the HTTP Host header on requests sent to the local service."""

    keep_alive_connections: Annotated[int, PropertyInfo(alias="keepAliveConnections")]
    """Maximum number of idle keepalive connections between Tunnel and your origin.

    This does not restrict the total number of concurrent connections.
    """

    keep_alive_timeout: Annotated[int, PropertyInfo(alias="keepAliveTimeout")]
    """Timeout after which an idle keepalive connection can be discarded."""

    match_sn_ito_host: Annotated[bool, PropertyInfo(alias="matchSNItoHost")]
    """Auto configure the Hostname on the origin server certificate."""

    no_happy_eyeballs: Annotated[bool, PropertyInfo(alias="noHappyEyeballs")]
    """
    Disable the “happy eyeballs” algorithm for IPv4/IPv6 fallback if your local
    network has misconfigured one of the protocols.
    """

    no_tls_verify: Annotated[bool, PropertyInfo(alias="noTLSVerify")]
    """Disables TLS verification of the certificate presented by your origin.

    Will allow any certificate from the origin to be accepted.
    """

    origin_server_name: Annotated[str, PropertyInfo(alias="originServerName")]
    """Hostname that cloudflared should expect from your origin server certificate."""

    proxy_type: Annotated[str, PropertyInfo(alias="proxyType")]
    """
    cloudflared starts a proxy server to translate HTTP traffic into TCP when
    proxying, for example, SSH or RDP. This configures what type of proxy will be
    started. Valid options are: "" for the regular proxy and "socks" for a SOCKS5
    proxy.
    """

    tcp_keep_alive: Annotated[int, PropertyInfo(alias="tcpKeepAlive")]
    """
    The timeout after which a TCP keepalive packet is sent on a connection between
    Tunnel and the origin server.
    """

    tls_timeout: Annotated[int, PropertyInfo(alias="tlsTimeout")]
    """
    Timeout for completing a TLS handshake to your origin server, if you have chosen
    to connect Tunnel to an HTTPS server.
    """


class ConfigIngress(TypedDict, total=False):
    """Public hostname"""

    hostname: Required[str]
    """Public hostname for this service."""

    service: Required[str]
    """Protocol and address of destination server.

    Supported protocols: http://, https://, unix://, tcp://, ssh://, rdp://,
    unix+tls://, smb://. Alternatively can return a HTTP status code
    http_status:[code] e.g. 'http_status:404'.
    """

    origin_request: Annotated[ConfigIngressOriginRequest, PropertyInfo(alias="originRequest")]
    """
    Configuration parameters for the public hostname specific connection settings
    between cloudflared and origin server.
    """

    path: str
    """Requests with this path route to this public hostname."""


class ConfigOriginRequestAccess(TypedDict, total=False):
    """
    For all L7 requests to this hostname, cloudflared will validate each request's Cf-Access-Jwt-Assertion request header.
    """

    aud_tag: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="audTag")]]
    """Access applications that are allowed to reach this hostname for this Tunnel.

    Audience tags can be identified in the dashboard or via the List Access policies
    API.
    """

    team_name: Required[Annotated[str, PropertyInfo(alias="teamName")]]

    required: bool
    """Deny traffic that has not fulfilled Access authorization."""


class ConfigOriginRequest(TypedDict, total=False):
    """
    Configuration parameters for the public hostname specific connection settings between cloudflared and origin server.
    """

    access: ConfigOriginRequestAccess
    """
    For all L7 requests to this hostname, cloudflared will validate each request's
    Cf-Access-Jwt-Assertion request header.
    """

    ca_pool: Annotated[str, PropertyInfo(alias="caPool")]
    """Path to the certificate authority (CA) for the certificate of your origin.

    This option should be used only if your certificate is not signed by Cloudflare.
    """

    connect_timeout: Annotated[int, PropertyInfo(alias="connectTimeout")]
    """Timeout for establishing a new TCP connection to your origin server.

    This excludes the time taken to establish TLS, which is controlled by
    tlsTimeout.
    """

    disable_chunked_encoding: Annotated[bool, PropertyInfo(alias="disableChunkedEncoding")]
    """Disables chunked transfer encoding. Useful if you are running a WSGI server."""

    http2_origin: Annotated[bool, PropertyInfo(alias="http2Origin")]
    """Attempt to connect to origin using HTTP2. Origin must be configured as https."""

    http_host_header: Annotated[str, PropertyInfo(alias="httpHostHeader")]
    """Sets the HTTP Host header on requests sent to the local service."""

    keep_alive_connections: Annotated[int, PropertyInfo(alias="keepAliveConnections")]
    """Maximum number of idle keepalive connections between Tunnel and your origin.

    This does not restrict the total number of concurrent connections.
    """

    keep_alive_timeout: Annotated[int, PropertyInfo(alias="keepAliveTimeout")]
    """Timeout after which an idle keepalive connection can be discarded."""

    match_sn_ito_host: Annotated[bool, PropertyInfo(alias="matchSNItoHost")]
    """Auto configure the Hostname on the origin server certificate."""

    no_happy_eyeballs: Annotated[bool, PropertyInfo(alias="noHappyEyeballs")]
    """
    Disable the “happy eyeballs” algorithm for IPv4/IPv6 fallback if your local
    network has misconfigured one of the protocols.
    """

    no_tls_verify: Annotated[bool, PropertyInfo(alias="noTLSVerify")]
    """Disables TLS verification of the certificate presented by your origin.

    Will allow any certificate from the origin to be accepted.
    """

    origin_server_name: Annotated[str, PropertyInfo(alias="originServerName")]
    """Hostname that cloudflared should expect from your origin server certificate."""

    proxy_type: Annotated[str, PropertyInfo(alias="proxyType")]
    """
    cloudflared starts a proxy server to translate HTTP traffic into TCP when
    proxying, for example, SSH or RDP. This configures what type of proxy will be
    started. Valid options are: "" for the regular proxy and "socks" for a SOCKS5
    proxy.
    """

    tcp_keep_alive: Annotated[int, PropertyInfo(alias="tcpKeepAlive")]
    """
    The timeout after which a TCP keepalive packet is sent on a connection between
    Tunnel and the origin server.
    """

    tls_timeout: Annotated[int, PropertyInfo(alias="tlsTimeout")]
    """
    Timeout for completing a TLS handshake to your origin server, if you have chosen
    to connect Tunnel to an HTTPS server.
    """


class Config(TypedDict, total=False):
    """The tunnel configuration and ingress rules."""

    ingress: Iterable[ConfigIngress]
    """List of public hostname definitions.

    At least one ingress rule needs to be defined for the tunnel.
    """

    origin_request: Annotated[ConfigOriginRequest, PropertyInfo(alias="originRequest")]
    """
    Configuration parameters for the public hostname specific connection settings
    between cloudflared and origin server.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ips import (
    IPsResource,
    AsyncIPsResource,
    IPsResourceWithRawResponse,
    AsyncIPsResourceWithRawResponse,
    IPsResourceWithStreamingResponse,
    AsyncIPsResourceWithStreamingResponse,
)
from .zones import (
    ZonesResource,
    AsyncZonesResource,
    ZonesResourceWithRawResponse,
    AsyncZonesResourceWithRawResponse,
    ZonesResourceWithStreamingResponse,
    AsyncZonesResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from .address_maps import (
    AddressMapsResource,
    AsyncAddressMapsResource,
    AddressMapsResourceWithRawResponse,
    AsyncAddressMapsResourceWithRawResponse,
    AddressMapsResourceWithStreamingResponse,
    AsyncAddressMapsResourceWithStreamingResponse,
)

__all__ = [
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
    "IPsResource",
    "AsyncIPsResource",
    "IPsResourceWithRawResponse",
    "AsyncIPsResourceWithRawResponse",
    "IPsResourceWithStreamingResponse",
    "AsyncIPsResourceWithStreamingResponse",
    "ZonesResource",
    "AsyncZonesResource",
    "ZonesResourceWithRawResponse",
    "AsyncZonesResourceWithRawResponse",
    "ZonesResourceWithStreamingResponse",
    "AsyncZonesResourceWithStreamingResponse",
    "AddressMapsResource",
    "AsyncAddressMapsResource",
    "AddressMapsResourceWithRawResponse",
    "AsyncAddressMapsResourceWithRawResponse",
    "AddressMapsResourceWithStreamingResponse",
    "AsyncAddressMapsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ase_get_params import AseGetParams as AseGetParams
from .ase_get_response import AseGetResponse as AseGetResponse
from .ase_prefixes_params import AsePrefixesParams as AsePrefixesParams
from .ase_prefixes_response import AsePrefixesResponse as AsePrefixesResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .site_location_param import SiteLocationParam

__all__ = ["SiteCreateParams"]


class SiteCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier"""

    name: Required[str]
    """The name of the site."""

    connector_id: str
    """Magic Connector identifier tag."""

    description: str

    ha_mode: bool
    """Site high availability mode.

    If set to true, the site can have two connectors and runs in high availability
    mode.
    """

    location: SiteLocationParam
    """Location of site in latitude and longitude."""

    secondary_connector_id: str
    """Magic Connector identifier tag. Used when high availability mode is on."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, cast

import httpx

from ..._types import Body, Query, Headers, NoneType, NotGiven, FileTypes, not_given
from ..._utils import extract_files, path_template, maybe_transform, deepcopy_minimal, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.cloudforce_one import binary_storage_create_params
from ...types.cloudforce_one.binary_storage_create_response import BinaryStorageCreateResponse

__all__ = ["BinaryStorageResource", "AsyncBinaryStorageResource"]


class BinaryStorageResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BinaryStorageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return BinaryStorageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BinaryStorageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return BinaryStorageResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        file: FileTypes,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryStorageCreateResponse:
        """
        Posts a file to Binary Storage

        Args:
          account_id: Account ID.

          file: The binary file content to upload.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            path_template("/accounts/{account_id}/cloudforce-one/binary", account_id=account_id),
            body=maybe_transform(body, binary_storage_create_params.BinaryStorageCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryStorageCreateResponse,
        )

    def get(
        self,
        hash: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Retrieves a file from Binary Storage

        Args:
          account_id: Account ID.

          hash: hash of the binary

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hash:
            raise ValueError(f"Expected a non-empty value for `hash` but received {hash!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/accounts/{account_id}/cloudforce-one/binary/{hash}", account_id=account_id, hash=hash),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncBinaryStorageResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBinaryStorageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncBinaryStorageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBinaryStorageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncBinaryStorageResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        file: FileTypes,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryStorageCreateResponse:
        """
        Posts a file to Binary Storage

        Args:
          account_id: Account ID.

          file: The binary file content to upload.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            path_template("/accounts/{account_id}/cloudforce-one/binary", account_id=account_id),
            body=await async_maybe_transform(body, binary_storage_create_params.BinaryStorageCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryStorageCreateResponse,
        )

    async def get(
        self,
        hash: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Retrieves a file from Binary Storage

        Args:
          account_id: Account ID.

          hash: hash of the binary

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hash:
            raise ValueError(f"Expected a non-empty value for `hash` but received {hash!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/accounts/{account_id}/cloudforce-one/binary/{hash}", account_id=account_id, hash=hash),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class BinaryStorageResourceWithRawResponse:
    def __init__(self, binary_storage: BinaryStorageResource) -> None:
        self._binary_storage = binary_storage

        self.create = to_raw_response_wrapper(
            binary_storage.create,
        )
        self.get = to_raw_response_wrapper(
            binary_storage.get,
        )


class AsyncBinaryStorageResourceWithRawResponse:
    def __init__(self, binary_storage: AsyncBinaryStorageResource) -> None:
        self._binary_storage = binary_storage

        self.create = async_to_raw_response_wrapper(
            binary_storage.create,
        )
        self.get = async_to_raw_response_wrapper(
            binary_storage.get,
        )


class BinaryStorageResourceWithStreamingResponse:
    def __init__(self, binary_storage: BinaryStorageResource) -> None:
        self._binary_storage = binary_storage

        self.create = to_streamed_response_wrapper(
            binary_storage.create,
        )
        self.get = to_streamed_response_wrapper(
            binary_storage.get,
        )


class AsyncBinaryStorageResourceWithStreamingResponse:
    def __init__(self, binary_storage: AsyncBinaryStorageResource) -> None:
        self._binary_storage = binary_storage

        self.create = async_to_streamed_response_wrapper(
            binary_storage.create,
        )
        self.get = async_to_streamed_response_wrapper(
            binary_storage.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .member_list_params import MemberListParams as MemberListParams
from .member_get_response import MemberGetResponse as MemberGetResponse
from .member_create_params import MemberCreateParams as MemberCreateParams
from .member_list_response import MemberListResponse as MemberListResponse
from .member_update_params import MemberUpdateParams as MemberUpdateParams
from .member_create_response import MemberCreateResponse as MemberCreateResponse
from .member_delete_response import MemberDeleteResponse as MemberDeleteResponse
from .member_update_response import MemberUpdateResponse as MemberUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .prioritize import (
    PrioritizeResource,
    AsyncPrioritizeResource,
    PrioritizeResourceWithRawResponse,
    AsyncPrioritizeResourceWithRawResponse,
    PrioritizeResourceWithStreamingResponse,
    AsyncPrioritizeResourceWithStreamingResponse,
)
from .custom_certificates import (
    CustomCertificatesResource,
    AsyncCustomCertificatesResource,
    CustomCertificatesResourceWithRawResponse,
    AsyncCustomCertificatesResourceWithRawResponse,
    CustomCertificatesResourceWithStreamingResponse,
    AsyncCustomCertificatesResourceWithStreamingResponse,
)

__all__ = [
    "PrioritizeResource",
    "AsyncPrioritizeResource",
    "PrioritizeResourceWithRawResponse",
    "AsyncPrioritizeResourceWithRawResponse",
    "PrioritizeResourceWithStreamingResponse",
    "AsyncPrioritizeResourceWithStreamingResponse",
    "CustomCertificatesResource",
    "AsyncCustomCertificatesResource",
    "CustomCertificatesResourceWithRawResponse",
    "AsyncCustomCertificatesResourceWithRawResponse",
    "CustomCertificatesResourceWithStreamingResponse",
    "AsyncCustomCertificatesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["ActiveSessionCreatePollResponse", "Data", "DataPoll", "DataPollOption", "DataPollOptionVote"]


class DataPollOptionVote(BaseModel):
    id: str

    name: str


class DataPollOption(BaseModel):
    count: float

    text: str
    """Text of the answer option"""

    votes: List[DataPollOptionVote]


class DataPoll(BaseModel):
    id: str
    """ID of the poll"""

    options: List[DataPollOption]
    """Answer options"""

    question: str
    """Question asked by the poll"""

    anonymous: Optional[bool] = None

    created_by: Optional[str] = None

    hide_votes: Optional[bool] = None

    voted: Optional[List[str]] = None


class Data(BaseModel):
    action: Optional[str] = None

    poll: Optional[DataPoll] = None


class ActiveSessionCreatePollResponse(BaseModel):
    data: Optional[Data] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["AbuseReportGetResponse", "MitigationSummary", "Submitter"]


class MitigationSummary(BaseModel):
    """A summary of the mitigations related to this report."""

    accepted_url_count: int
    """How many of the reported URLs were confirmed as abusive."""

    active_count: int
    """How many mitigations are active."""

    external_host_notified: bool
    """Whether the report has been forwarded to an external hosting provider."""

    in_review_count: int
    """How many mitigations are under review."""

    pending_count: int
    """How many mitigations are pending their effective date."""


class Submitter(BaseModel):
    """Information about the submitter of the report."""

    company: Optional[str] = None

    email: Optional[str] = None

    name: Optional[str] = None

    telephone: Optional[str] = None


class AbuseReportGetResponse(BaseModel):
    id: str
    """Public facing ID of abuse report, aka abuse_rand."""

    cdate: str
    """Creation date of report.

    Time in RFC 3339 format (https://www.rfc-editor.org/rfc/rfc3339.html)
    """

    domain: str
    """Domain that relates to the report."""

    mitigation_summary: MitigationSummary
    """A summary of the mitigations related to this report."""

    status: Literal["accepted", "in_review"]
    """An enum value that represents the status of an abuse record"""

    type: Literal["PHISH", "GEN", "THREAT", "DMCA", "EMER", "TM", "REG_WHO", "NCSEI", "NETWORK"]
    """The abuse report type"""

    justification: Optional[str] = None
    """Justification for the report."""

    original_work: Optional[str] = None
    """Original work / Targeted brand in the alleged abuse."""

    submitter: Optional[Submitter] = None
    """Information about the submitter of the report."""

    urls: Optional[List[str]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .dns import DNS as DNS
from .edge_ips import EdgeIPs as EdgeIPs
from .dns_param import DNSParam as DNSParam
from .origin_dns import OriginDNS as OriginDNS
from .origin_port import OriginPort as OriginPort
from .edge_ips_param import EdgeIPsParam as EdgeIPsParam
from .app_list_params import AppListParams as AppListParams
from .app_get_response import AppGetResponse as AppGetResponse
from .origin_dns_param import OriginDNSParam as OriginDNSParam
from .app_create_params import AppCreateParams as AppCreateParams
from .app_list_response import AppListResponse as AppListResponse
from .app_update_params import AppUpdateParams as AppUpdateParams
from .origin_port_param import OriginPortParam as OriginPortParam
from .app_create_response import AppCreateResponse as AppCreateResponse
from .app_delete_response import AppDeleteResponse as AppDeleteResponse
from .app_update_response import AppUpdateResponse as AppUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

from ..._types import SequenceNotStr

__all__ = ["MigrationStepParam", "RenamedClass", "TransferredClass"]

_RenamedClassReservedKeywords = TypedDict(
    "_RenamedClassReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class RenamedClass(_RenamedClassReservedKeywords, total=False):
    to: str


_TransferredClassReservedKeywords = TypedDict(
    "_TransferredClassReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class TransferredClass(_TransferredClassReservedKeywords, total=False):
    from_script: str

    to: str


class MigrationStepParam(TypedDict, total=False):
    deleted_classes: SequenceNotStr[str]
    """A list of classes to delete Durable Object namespaces from."""

    new_classes: SequenceNotStr[str]
    """A list of classes to create Durable Object namespaces from."""

    new_sqlite_classes: SequenceNotStr[str]
    """A list of classes to create Durable Object namespaces with SQLite from."""

    renamed_classes: Iterable[RenamedClass]
    """A list of classes with Durable Object namespaces that were renamed."""

    transferred_classes: Iterable[TransferredClass]
    """
    A list of transfers for Durable Object namespaces from a different Worker and
    class to a class defined in this Worker.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Required, TypeAlias, TypedDict

__all__ = [
    "SplitTunnelExcludeParam",
    "TeamsDevicesExcludeSplitTunnelWithAddress",
    "TeamsDevicesExcludeSplitTunnelWithHost",
]


class TeamsDevicesExcludeSplitTunnelWithAddress(TypedDict, total=False):
    address: Required[str]
    """The address in CIDR format to exclude from the tunnel.

    If `address` is present, `host` must not be present.
    """

    description: str
    """A description of the Split Tunnel item, displayed in the client UI."""


class TeamsDevicesExcludeSplitTunnelWithHost(TypedDict, total=False):
    host: Required[str]
    """The domain name to exclude from the tunnel.

    If `host` is present, `address` must not be present.
    """

    description: str
    """A description of the Split Tunnel item, displayed in the client UI."""


SplitTunnelExcludeParam: TypeAlias = Union[
    TeamsDevicesExcludeSplitTunnelWithAddress, TeamsDevicesExcludeSplitTunnelWithHost
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["LockdownCIDRConfigurationParam"]


class LockdownCIDRConfigurationParam(TypedDict, total=False):
    target: Literal["ip_range"]
    """The configuration target.

    You must set the target to `ip_range` when specifying an IP address range in the
    Zone Lockdown rule.
    """

    value: str
    """The IP address range to match. You can only use prefix lengths `/16` and `/24`."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["RecipientListParams"]


class RecipientListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier."""

    include_resources: bool
    """Include resources in the response."""

    page: int
    """Page number."""

    per_page: int
    """Number of objects to return per page."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ..._utils import PropertyInfo

__all__ = [
    "ZoneTagUpdateParams",
    "ResourceTaggingSetTagsRequestZoneLevelBase",
    "ResourceTaggingSetTagsRequestZoneLevelAccessApplicationPolicy",
]


class ResourceTaggingSetTagsRequestZoneLevelBase(TypedDict, total=False):
    zone_id: Required[str]
    """Zone ID is required only for zone-level resources"""

    resource_id: Required[str]
    """Identifies the unique resource."""

    resource_type: Required[
        Literal[
            "api_gateway_operation",
            "custom_certificate",
            "custom_hostname",
            "dns_record",
            "managed_client_certificate",
            "zone",
        ]
    ]
    """Enum for base zone-level resource types (those with no extra required fields)."""

    tags: Dict[str, str]
    """Contains key-value pairs of tags."""

    if_match: Annotated[str, PropertyInfo(alias="If-Match")]


class ResourceTaggingSetTagsRequestZoneLevelAccessApplicationPolicy(TypedDict, total=False):
    zone_id: Required[str]
    """Zone ID is required only for zone-level resources"""

    access_application_id: Required[str]
    """Access application ID is required only for access_application_policy resources"""

    resource_id: Required[str]
    """Identifies the unique resource."""

    resource_type: Required[
        Literal[
            "api_gateway_operation",
            "custom_certificate",
            "custom_hostname",
            "dns_record",
            "managed_client_certificate",
            "zone",
            "access_application_policy",
        ]
    ]
    """Enum for base zone-level resource types (those with no extra required fields)."""

    tags: Dict[str, str]
    """Contains key-value pairs of tags."""

    if_match: Annotated[str, PropertyInfo(alias="If-Match")]


ZoneTagUpdateParams: TypeAlias = Union[
    ResourceTaggingSetTagsRequestZoneLevelBase, ResourceTaggingSetTagsRequestZoneLevelAccessApplicationPolicy
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .address_space_edit_params import AddressSpaceEditParams as AddressSpaceEditParams
from .address_space_edit_response import AddressSpaceEditResponse as AddressSpaceEditResponse
from .address_space_list_response import AddressSpaceListResponse as AddressSpaceListResponse
from .address_space_update_params import AddressSpaceUpdateParams as AddressSpaceUpdateParams
from .address_space_update_response import AddressSpaceUpdateResponse as AddressSpaceUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .summary_arc_params import SummaryARCParams as SummaryARCParams
from .summary_spf_params import SummarySPFParams as SummarySPFParams
from .summary_dkim_params import SummaryDKIMParams as SummaryDKIMParams
from .summary_spam_params import SummarySpamParams as SummarySpamParams
from .summary_arc_response import SummaryARCResponse as SummaryARCResponse
from .summary_dmarc_params import SummaryDMARCParams as SummaryDMARCParams
from .summary_spf_response import SummarySPFResponse as SummarySPFResponse
from .summary_spoof_params import SummarySpoofParams as SummarySpoofParams
from .summary_dkim_response import SummaryDKIMResponse as SummaryDKIMResponse
from .summary_spam_response import SummarySpamResponse as SummarySpamResponse
from .summary_dmarc_response import SummaryDMARCResponse as SummaryDMARCResponse
from .summary_spoof_response import SummarySpoofResponse as SummarySpoofResponse
from .summary_malicious_params import SummaryMaliciousParams as SummaryMaliciousParams
from .summary_malicious_response import SummaryMaliciousResponse as SummaryMaliciousResponse
from .summary_tls_version_params import SummaryTLSVersionParams as SummaryTLSVersionParams
from .timeseries_group_arc_params import TimeseriesGroupARCParams as TimeseriesGroupARCParams
from .timeseries_group_spf_params import TimeseriesGroupSPFParams as TimeseriesGroupSPFParams
from .summary_tls_version_response import SummaryTLSVersionResponse as SummaryTLSVersionResponse
from .timeseries_group_dkim_params import TimeseriesGroupDKIMParams as TimeseriesGroupDKIMParams
from .timeseries_group_spam_params import TimeseriesGroupSpamParams as TimeseriesGroupSpamParams
from .timeseries_group_arc_response import TimeseriesGroupARCResponse as TimeseriesGroupARCResponse
from .timeseries_group_dmarc_params import TimeseriesGroupDMARCParams as TimeseriesGroupDMARCParams
from .timeseries_group_spf_response import TimeseriesGroupSPFResponse as TimeseriesGroupSPFResponse
from .timeseries_group_spoof_params import TimeseriesGroupSpoofParams as TimeseriesGroupSpoofParams
from .summary_threat_category_params import SummaryThreatCategoryParams as SummaryThreatCategoryParams
from .timeseries_group_dkim_response import TimeseriesGroupDKIMResponse as TimeseriesGroupDKIMResponse
from .timeseries_group_spam_response import TimeseriesGroupSpamResponse as TimeseriesGroupSpamResponse
from .timeseries_group_dmarc_response import TimeseriesGroupDMARCResponse as TimeseriesGroupDMARCResponse
from .timeseries_group_spoof_response import TimeseriesGroupSpoofResponse as TimeseriesGroupSpoofResponse
from .summary_threat_category_response import SummaryThreatCategoryResponse as SummaryThreatCategoryResponse
from .timeseries_group_malicious_params import TimeseriesGroupMaliciousParams as TimeseriesGroupMaliciousParams
from .timeseries_group_malicious_response import TimeseriesGroupMaliciousResponse as TimeseriesGroupMaliciousResponse
from .timeseries_group_tls_version_params import TimeseriesGroupTLSVersionParams as TimeseriesGroupTLSVersionParams
from .timeseries_group_tls_version_response import (
    TimeseriesGroupTLSVersionResponse as TimeseriesGroupTLSVersionResponse,
)
from .timeseries_group_threat_category_params import (
    TimeseriesGroupThreatCategoryParams as TimeseriesGroupThreatCategoryParams,
)
from .timeseries_group_threat_category_response import (
    TimeseriesGroupThreatCategoryResponse as TimeseriesGroupThreatCategoryResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["BillingCreditBalanceResponse", "PaymentMethod", "TopupConfig"]


class PaymentMethod(BaseModel):
    brand: Optional[str] = None

    last4: Optional[str] = None


class TopupConfig(BaseModel):
    amount: Optional[float] = None

    disabled_reason: Optional[str] = FieldInfo(alias="disabledReason", default=None)

    error: Optional[str] = None

    last_failed_at: Optional[float] = FieldInfo(alias="lastFailedAt", default=None)

    threshold: Optional[float] = None


class BillingCreditBalanceResponse(BaseModel):
    balance: float

    has_default_payment_method: bool

    payment_method: Optional[PaymentMethod] = None

    topup_config: TopupConfig

    first_topup_success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .bot_management import (
    BotManagementResource,
    AsyncBotManagementResource,
    BotManagementResourceWithRawResponse,
    AsyncBotManagementResourceWithRawResponse,
    BotManagementResourceWithStreamingResponse,
    AsyncBotManagementResourceWithStreamingResponse,
)

__all__ = [
    "BotManagementResource",
    "AsyncBotManagementResource",
    "BotManagementResourceWithRawResponse",
    "AsyncBotManagementResourceWithRawResponse",
    "BotManagementResourceWithStreamingResponse",
    "AsyncBotManagementResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tests import Tests as Tests
from .live_stat import LiveStat as LiveStat
from .traceroute import Traceroute as Traceroute
from .http_details import HTTPDetails as HTTPDetails
from .colo_list_params import ColoListParams as ColoListParams
from .rule_list_params import RuleListParams as RuleListParams
from .test_list_params import TestListParams as TestListParams
from .rule_get_response import RuleGetResponse as RuleGetResponse
from .colo_list_response import ColoListResponse as ColoListResponse
from .rule_create_params import RuleCreateParams as RuleCreateParams
from .rule_list_response import RuleListResponse as RuleListResponse
from .rule_update_params import RuleUpdateParams as RuleUpdateParams
from .command_list_params import CommandListParams as CommandListParams
from .http_test_get_params import HTTPTestGetParams as HTTPTestGetParams
from .rule_create_response import RuleCreateResponse as RuleCreateResponse
from .rule_delete_response import RuleDeleteResponse as RuleDeleteResponse
from .rule_update_response import RuleUpdateResponse as RuleUpdateResponse
from .aggregate_time_period import AggregateTimePeriod as AggregateTimePeriod
from .command_create_params import CommandCreateParams as CommandCreateParams
from .command_list_response import CommandListResponse as CommandListResponse
from .command_create_response import CommandCreateResponse as CommandCreateResponse
from .fleet_status_live_params import FleetStatusLiveParams as FleetStatusLiveParams
from .fleet_status_live_response import FleetStatusLiveResponse as FleetStatusLiveResponse
from .traceroute_test_get_params import TracerouteTestGetParams as TracerouteTestGetParams
from .warp_change_event_get_params import WARPChangeEventGetParams as WARPChangeEventGetParams
from .fleet_status_over_time_params import FleetStatusOverTimeParams as FleetStatusOverTimeParams
from .warp_change_event_get_response import WARPChangeEventGetResponse as WARPChangeEventGetResponse
from .fleet_status_over_time_response import FleetStatusOverTimeResponse as FleetStatusOverTimeResponse
from .traceroute_test_percentiles_params import TracerouteTestPercentilesParams as TracerouteTestPercentilesParams
from .traceroute_test_network_path_params import TracerouteTestNetworkPathParams as TracerouteTestNetworkPathParams
from .traceroute_test_percentiles_response import TracerouteTestPercentilesResponse as TracerouteTestPercentilesResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["PolicyFilter"]


class PolicyFilter(BaseModel):
    """
    Optional filters that allow you to be alerted only on a subset of events for that alert type based on some criteria. This is only available for select alert types. See alert type documentation for more details.
    """

    actions: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    affected_asns: Optional[List[str]] = None
    """Used for configuring radar_notification"""

    affected_components: Optional[List[str]] = None
    """Used for configuring incident_alert"""

    affected_locations: Optional[List[str]] = None
    """Used for configuring radar_notification"""

    airport_code: Optional[List[str]] = None
    """Used for configuring maintenance_event_notification"""

    alert_trigger_preferences: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    alert_trigger_preferences_value: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    enabled: Optional[List[str]] = None
    """Used for configuring load_balancing_pool_enablement_alert"""

    environment: Optional[List[str]] = None
    """Used for configuring pages_event_alert"""

    event: Optional[List[str]] = None
    """Used for configuring pages_event_alert"""

    event_source: Optional[List[str]] = None
    """Used for configuring load_balancing_health_alert"""

    event_type: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    group_by: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    health_check_id: Optional[List[str]] = None
    """Used for configuring health_check_status_notification"""

    incident_impact: Optional[
        List[
            Literal[
                "INCIDENT_IMPACT_NONE", "INCIDENT_IMPACT_MINOR", "INCIDENT_IMPACT_MAJOR", "INCIDENT_IMPACT_CRITICAL"
            ]
        ]
    ] = None
    """Used for configuring incident_alert"""

    input_id: Optional[List[str]] = None
    """Used for configuring stream_live_notifications"""

    insight_class: Optional[List[str]] = None
    """Used for configuring security_insights_alert"""

    limit: Optional[List[str]] = None
    """Used for configuring billing_usage_alert"""

    logo_tag: Optional[List[str]] = None
    """Used for configuring logo_match_alert"""

    megabits_per_second: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l4_alert"""

    new_health: Optional[List[str]] = None
    """Used for configuring load_balancing_health_alert"""

    new_status: Optional[List[str]] = None
    """Used for configuring tunnel_health_event"""

    packets_per_second: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l4_alert"""

    pool_id: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    pop_names: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    product: Optional[List[str]] = None
    """Used for configuring billing_usage_alert"""

    project_id: Optional[List[str]] = None
    """Used for configuring pages_event_alert"""

    protocol: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l4_alert"""

    query_tag: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    requests_per_second: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l7_alert"""

    selectors: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    services: Optional[List[str]] = None
    """Used for configuring clickhouse_alert_fw_ent_anomaly"""

    slo: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    status: Optional[List[str]] = None
    """Used for configuring health_check_status_notification"""

    target_hostname: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l7_alert"""

    target_ip: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l4_alert"""

    target_zone_name: Optional[List[str]] = None
    """Used for configuring advanced_ddos_attack_l7_alert"""

    traffic_exclusions: Optional[List[Literal["security_events"]]] = None
    """Used for configuring traffic_anomalies_alert"""

    tunnel_id: Optional[List[str]] = None
    """Used for configuring tunnel_health_event"""

    tunnel_name: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    type: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    where: Optional[List[str]] = None
    """Usage depends on specific alert type"""

    zones: Optional[List[str]] = None
    """Usage depends on specific alert type"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ....._types import Body, Query, Headers, NotGiven, not_given
from ....._utils import path_template
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options

__all__ = ["VttResource", "AsyncVttResource"]


class VttResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VttResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return VttResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VttResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return VttResourceWithStreamingResponse(self)

    def get(
        self,
        language: str,
        *,
        account_id: str,
        identifier: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Return WebVTT captions for a provided language.

        Args:
          account_id: Identifier.

          identifier: A Cloudflare-generated unique identifier for a media item.

          language: The language tag in BCP 47 format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not identifier:
            raise ValueError(f"Expected a non-empty value for `identifier` but received {identifier!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        extra_headers = {"Accept": "text/vtt", **(extra_headers or {})}
        return self._get(
            path_template(
                "/accounts/{account_id}/stream/{identifier}/captions/{language}/vtt",
                account_id=account_id,
                identifier=identifier,
                language=language,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncVttResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVttResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVttResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVttResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncVttResourceWithStreamingResponse(self)

    async def get(
        self,
        language: str,
        *,
        account_id: str,
        identifier: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Return WebVTT captions for a provided language.

        Args:
          account_id: Identifier.

          identifier: A Cloudflare-generated unique identifier for a media item.

          language: The language tag in BCP 47 format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not identifier:
            raise ValueError(f"Expected a non-empty value for `identifier` but received {identifier!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        extra_headers = {"Accept": "text/vtt", **(extra_headers or {})}
        return await self._get(
            path_template(
                "/accounts/{account_id}/stream/{identifier}/captions/{language}/vtt",
                account_id=account_id,
                identifier=identifier,
                language=language,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class VttResourceWithRawResponse:
    def __init__(self, vtt: VttResource) -> None:
        self._vtt = vtt

        self.get = to_raw_response_wrapper(
            vtt.get,
        )


class AsyncVttResourceWithRawResponse:
    def __init__(self, vtt: AsyncVttResource) -> None:
        self._vtt = vtt

        self.get = async_to_raw_response_wrapper(
            vtt.get,
        )


class VttResourceWithStreamingResponse:
    def __init__(self, vtt: VttResource) -> None:
        self._vtt = vtt

        self.get = to_streamed_response_wrapper(
            vtt.get,
        )


class AsyncVttResourceWithStreamingResponse:
    def __init__(self, vtt: AsyncVttResource) -> None:
        self._vtt = vtt

        self.get = async_to_streamed_response_wrapper(
            vtt.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ....._models import BaseModel

__all__ = ["TargetListResponse", "IP", "IPIPV4", "IPIPV6"]


class IPIPV4(BaseModel):
    """The target's IPv4 address"""

    ip_addr: Optional[str] = None
    """IP address of the target"""

    virtual_network_id: Optional[str] = None
    """(optional) Private virtual network identifier for the target.

    If omitted, the default virtual network ID will be used.
    """


class IPIPV6(BaseModel):
    """The target's IPv6 address"""

    ip_addr: Optional[str] = None
    """IP address of the target"""

    virtual_network_id: Optional[str] = None
    """(optional) Private virtual network identifier for the target.

    If omitted, the default virtual network ID will be used.
    """


class IP(BaseModel):
    """The IPv4/IPv6 address that identifies where to reach a target"""

    ipv4: Optional[IPIPV4] = None
    """The target's IPv4 address"""

    ipv6: Optional[IPIPV6] = None
    """The target's IPv6 address"""


class TargetListResponse(BaseModel):
    id: str
    """Target identifier"""

    created_at: datetime
    """Date and time at which the target was created"""

    hostname: str
    """A non-unique field that refers to a target"""

    ip: IP
    """The IPv4/IPv6 address that identifies where to reach a target"""

    modified_at: datetime
    """Date and time at which the target was modified"""
